@@ -17,7 +17,6 @@
 from .initializer import DataFrame, Series, Index, named_dataframe, named_series
 # do imports to register operands
 from .base.cut import cut
-from .base.checkna import isna, isnull, notna, notnull
 from .base.melt import melt
 from .base.qcut import qcut
 from .datasource.from_tensor import dataframe_from_tensor, series_from_tensor
@@ -29,6 +28,7 @@ from .datasource.read_parquet import read_parquet
 from .datasource.date_range import date_range
 from .fetch import DataFrameFetch, DataFrameFetchShuffle
 from .merge import concat, merge
+from .missing.checkna import isna, isnull, notna, notnull
 from .reduction import CustomReduction, unique
 from .tseries.to_datetime import to_datetime
 
@@ -36,6 +36,7 @@ from . import arithmetic
 from . import base
 from . import indexing
 from . import merge as merge_
+from . import missing
 from . import reduction
 from . import statistics
 from . import sort
@@ -45,8 +46,8 @@ from . import datastore
 from . import window
 from . import plotting
 
-del reduction, statistics, arithmetic, indexing, merge_, \
-    base, groupby, ufunc, datastore, sort, window, plotting
+del reduction, statistics, arithmetic, indexing, merge_, base, groupby, \
+    missing, ufunc, datastore, sort, window, plotting
 del DataFrameFetch, DataFrameFetchShuffle
 
 # noinspection PyUnresolvedReferences
