@@ -14,11 +14,11 @@
 
 from ... import opcodes as OperandDef
 from ...utils import classproperty
-from .core import DataFrameBinOpMixin, DataFrameBinOp
+from .core import DataFrameBinopUfunc
 from .docstring import bin_compare_doc
 
 
-class DataFrameGreater(DataFrameBinOp, DataFrameBinOpMixin):
+class DataFrameGreater(DataFrameBinopUfunc):
     _op_type_ = OperandDef.GT
 
     _func_name = 'gt'
@@ -28,6 +28,11 @@ class DataFrameGreater(DataFrameBinOp, DataFrameBinOpMixin):
     def _operator(self):
         return lambda lhs, rhs: lhs.gt(rhs)
 
+    @classproperty
+    def tensor_op_type(self):
+        from ...tensor.arithmetic import TensorGreaterThan
+        return TensorGreaterThan
+
 
 _gt_example = """
 >>> a.gt(b, fill_value=0).execute()
