@@ -18,11 +18,8 @@ from .to_cpu import to_cpu
 from .rechunk import rechunk
 from .describe import describe
 from .apply import df_apply, series_apply
-from .fillna import fillna, ffill, bfill
 from .transform import df_transform, series_transform
 from .isin import series_isin, df_isin
-from .checkna import isna, notna, isnull, notnull
-from .dropna import df_dropna, series_dropna
 from .cut import cut
 from .qcut import qcut
 from .shift import shift, tshift
@@ -36,6 +33,7 @@ from .melt import melt
 from .memory_usage import df_memory_usage, series_memory_usage, index_memory_usage
 from .select_dtypes import select_dtypes
 from .map_chunk import map_chunk
+from .cartesian_chunk import cartesian_chunk
 from .rebalance import rebalance
 from .stack import stack
 from .explode import df_explode, series_explode
@@ -55,15 +53,7 @@ def _install():
         setattr(t, 'describe', describe)
         setattr(t, 'apply', df_apply)
         setattr(t, 'transform', df_transform)
-        setattr(t, 'fillna', fillna)
-        setattr(t, 'ffill', ffill)
-        setattr(t, 'bfill', bfill)
         setattr(t, 'isin', df_isin)
-        setattr(t, 'isna', isna)
-        setattr(t, 'isnull', isnull)
-        setattr(t, 'notna', notna)
-        setattr(t, 'notnull', notnull)
-        setattr(t, 'dropna', df_dropna)
         setattr(t, 'shift', shift)
         setattr(t, 'tshift', tshift)
         setattr(t, 'diff', df_diff)
@@ -76,6 +66,7 @@ def _install():
         setattr(t, 'memory_usage', df_memory_usage)
         setattr(t, 'select_dtypes', select_dtypes)
         setattr(t, 'map_chunk', map_chunk)
+        setattr(t, 'cartesian_chunk', cartesian_chunk)
         setattr(t, 'rebalance', rebalance)
         setattr(t, 'stack', stack)
         setattr(t, 'explode', df_explode)
@@ -88,15 +79,7 @@ def _install():
         setattr(t, 'describe', describe)
         setattr(t, 'apply', series_apply)
         setattr(t, 'transform', series_transform)
-        setattr(t, 'fillna', fillna)
-        setattr(t, 'ffill', ffill)
-        setattr(t, 'bfill', bfill)
         setattr(t, 'isin', series_isin)
-        setattr(t, 'isna', isna)
-        setattr(t, 'isnull', isnull)
-        setattr(t, 'notna', notna)
-        setattr(t, 'notnull', notnull)
-        setattr(t, 'dropna', series_dropna)
         setattr(t, 'shift', shift)
         setattr(t, 'tshift', tshift)
         setattr(t, 'diff', series_diff)
@@ -106,6 +89,7 @@ def _install():
         setattr(t, 'drop_duplicates', series_drop_duplicates)
         setattr(t, 'memory_usage', series_memory_usage)
         setattr(t, 'map_chunk', map_chunk)
+        setattr(t, 'cartesian_chunk', cartesian_chunk)
         setattr(t, 'rebalance', rebalance)
         setattr(t, 'explode', series_explode)
 
