@@ -23,6 +23,7 @@ from numbers import Integral
 import numpy as np
 import pandas as pd
 from pandas.api.types import is_string_dtype
+from pandas.api.extensions import ExtensionDtype
 from pandas.core.dtypes.cast import find_common_type
 try:
     import pyarrow as pa
@@ -190,6 +191,10 @@ def decide_series_chunk_size(shape, chunk_size, memory_usage):
     if len(chunk_size) == len(shape):
         return normalize_chunk_sizes(shape, chunk_size[0])
 
+    if all(s == 0 for s in shape):
+        # skip when shape is 0
+        return tuple((s,) for s in shape)
+
     max_chunk_size = options.chunk_store_limit
     series_chunk_size = max_chunk_size / average_memory_usage
     return normalize_chunk_sizes(shape, int(series_chunk_size))
@@ -1021,6 +1026,23 @@ def to_arrow_dtypes(dtypes, test_df=None):
     return new_dtypes
 
 
+def make_dtype(dtype):
+    if isinstance(dtype, (np.dtype, ExtensionDtype)):
+        return dtype
+    return np.dtype(dtype) if dtype is not None else None
+
+
+def make_dtypes(dtypes):
+    if dtypes is None:
+        return None
+    if not isinstance(dtypes, pd.Series):
+        if isinstance(dtypes, dict):
+            dtypes = pd.Series(dtypes.values(), index=dtypes.keys())
+        else:
+            dtypes = pd.Series(dtypes)
+    return dtypes.apply(make_dtype)
+
+
 _io_quiet_local = threading.local()
 _io_quiet_lock = threading.Lock()
 
